library(tidyverse)
library(lmerTest)

# read raw data
data1 <- read.csv("data/validation_study_raw.csv")

# delete header row and practice data
data2 <- data1[-c(1:2),]

# create participant index
data2$id <- 1:nrow(data2)

# convert age to numeric
mean(as.numeric(data2$Age))

# convert from wide to long with rating variables for science and profunding ratings
data_sbs <- gather(data2, key = "trial", value = "rating", contains("science"))
data_ppbs <- gather(data2, key = "trial", value = "rating", contains("spirit"))
data_sbs2 <- data_sbs[,-c(3:5,7:37)]
data_ppbs2 <- data_ppbs[,-c(3:5,7:37)]
data_sbs2 <- separate(data_sbs2, trial, c("trial2", NA), "_")
data_ppbs2 <- separate(data_ppbs2, trial, c("trial2", NA), "_")
data_sbs2$trial <-as.numeric(gsub("X", "", data_sbs2$trial2))
data_sbs2$rating <- as.numeric(data_sbs2$rating)
data_ppbs2$trial <-as.numeric(gsub("X", "", data_ppbs2$trial2))
data_ppbs2$rating <- as.numeric(data_ppbs2$rating)

# create variable to identify scientific and profound items
data_ppbs2$science <- ifelse(data_ppbs2$trial > 10, .5, -.5)
data_sbs2$science <- ifelse(data_sbs2$trial > 10, .5, -.5)

# test the effects of item type on profundity ratings
model_ppbs <- lmer(rating~science+(1|id)+(1|trial), data=data_ppbs2)
summary(model_ppbs)

# test the effects of item type on science ratings
model_sbs <- lmer(rating~science+(1|id)+(1|trial), data=data_sbs2)
summary(model_sbs)

# profound-sounding means & sds
data_ppbs2 %>%
  group_by(science) %>%
  summarize(mean=mean(rating, na.rm=TRUE),
            sd=sd(rating, na.rm=TRUE))

# scientific-sounding means & sds
data_sbs2 %>%
  group_by(science) %>%
  summarize(mean=mean(rating),
            sd=sd(rating))

#demographics
data2$age <- as.integer(paste(data2$Age))
mean(data2$Age, na.rm=TRUE)
sd(data2$Age, na.rm=TRUE)
table(data2$Gender)
78+116